@@ -15,6 +15,7 @@ import (
 	"github.com/abiosoft/colima/environment"
 	"github.com/abiosoft/colima/environment/container/containerd"
 	"github.com/abiosoft/colima/environment/container/docker"
+	"github.com/abiosoft/colima/environment/container/incus"
 	"github.com/abiosoft/colima/environment/container/kubernetes"
 	"github.com/abiosoft/colima/environment/host"
 	"github.com/abiosoft/colima/environment/vm/lima"
@@ -295,17 +296,20 @@ func (c colimaApp) SSH(args ...string) error {
 }
 
 type statusInfo struct {
-	DisplayName  string `json:"display_name"`
-	Driver       string `json:"driver"`
-	Arch         string `json:"arch"`
-	Runtime      string `json:"runtime"`
-	MountType    string `json:"mount_type"`
-	IPAddress    string `json:"ip_address"`
-	DockerSocket string `json:"docker_socket"`
-	Kubernetes   bool   `json:"kubernetes"`
-	CPU          int    `json:"cpu"`
-	Memory       int64  `json:"memory"`
-	Disk         int64  `json:"disk"`
+	DisplayName      string `json:"display_name"`
+	Driver           string `json:"driver"`
+	Arch             string `json:"arch"`
+	Runtime          string `json:"runtime"`
+	MountType        string `json:"mount_type"`
+	IPAddress        string `json:"ip_address,omitempty"`
+	DockerSocket     string `json:"docker_socket,omitempty"`
+	ContainerdSocket string `json:"containerd_socket,omitempty"`
+	BuildkitdSocket  string `json:"buildkitd_socket,omitempty"`
+	IncusSocket      string `json:"incus_socket,omitempty"`
+	Kubernetes       bool   `json:"kubernetes"`
+	CPU              int    `json:"cpu"`
+	Memory           int64  `json:"memory"`
+	Disk             int64  `json:"disk"`
 }
 
 func (c colimaApp) getStatus() (status statusInfo, err error) {
@@ -334,6 +338,14 @@ func (c colimaApp) getStatus() (status statusInfo, err error) {
 	}
 	if currentRuntime == docker.Name {
 		status.DockerSocket = "unix://" + docker.HostSocketFile()
+		status.ContainerdSocket = "unix://" + containerd.HostSocketFiles().Containerd
+	}
+	if currentRuntime == containerd.Name {
+		status.ContainerdSocket = "unix://" + containerd.HostSocketFiles().Containerd
+		status.BuildkitdSocket = "unix://" + containerd.HostSocketFiles().Buildkitd
+	}
+	if currentRuntime == incus.Name {
+		status.IncusSocket = "unix://" + incus.HostSocketFile()
 	}
 	if k, err := c.Kubernetes(); err == nil && k.Running(ctx) {
 		status.Kubernetes = true
@@ -357,7 +369,6 @@ func (c colimaApp) Status(extended bool, jsonOutput bool) error {
 			return fmt.Errorf("error encoding status as json: %w", err)
 		}
 	} else {
-
 		log.Println(config.CurrentProfile().DisplayName, "is running using", status.Driver)
 		log.Println("arch:", status.Arch)
 		log.Println("runtime:", status.Runtime)
@@ -372,7 +383,16 @@ func (c colimaApp) Status(extended bool, jsonOutput bool) error {
 
 		// docker socket
 		if status.DockerSocket != "" {
-			log.Println("socket:", status.DockerSocket)
+			log.Println("docker socket:", status.DockerSocket)
+		}
+		if status.ContainerdSocket != "" {
+			log.Println("containerd socket:", status.ContainerdSocket)
+		}
+		if status.BuildkitdSocket != "" {
+			log.Println("buildkitd socket:", status.BuildkitdSocket)
+		}
+		if status.IncusSocket != "" {
+			log.Println("incus socket:", status.IncusSocket)
 		}
 
 		// kubernetes
