@@ -92,10 +92,12 @@ func launchEditor(editor string, file string) error {
 		return fmt.Errorf("no editor found in $PATH, kindly set $EDITOR environment variable and try again")
 	}
 
-	// vscode needs the wait flag, add it if the user did not.
+	// some editors need the wait flag, let us add it if the user has not.
 	switch editor {
 	case "code", "code-insiders", "code-oss", "codium", "/Applications/Visual Studio Code.app/Contents/Resources/app/bin/code":
 		editor = strconv.Quote(editor) + " --wait --new-window"
+	case "mate", "/Applications/TextMate 2.app/Contents/MacOS/mate", "/Applications/TextMate 2.app/Contents/MacOS/TextMate":
+		editor = strconv.Quote(editor) + " --wait"
 	}
 
 	return cli.CommandInteractive("sh", "-c", editor+" "+file).Run()
